module.exports = {
  checkParams,
  resetCache
};

function checkParams(params) {
  const paramsKeys = Object.keys(params);
  if (paramsKeys.length > 0) {
    const hasValidParams = paramsKeys.every((key) =>
      ['cacheRefresh', 'cacheElemRefresh'].includes(key)
    );
    if (!hasValidParams) {
      throw Error('Invalid parameters. Valid ones are cacheElemRefresh or cacheRefresh');
    }
  }
}

function resetCache({ obj, prop, cacheRefresh, cacheElemRefresh }) {
  const currentTime = new Date().getTime();
  const cacheCreatedTime = obj.createdAt.getTime();
  const cacheElemCreatedTime = obj[prop].createdAt.getTime();
  const timeSinceCacheElemInit = currentTime - cacheElemCreatedTime;
  const timeSinceCacheInit = currentTime - cacheCreatedTime;
  if (process.env.DEBUG) {
    console.log({ timeSinceCacheElemInit, timeSinceCacheInit });
  }
  if (cacheRefresh && timeSinceCacheInit > cacheRefresh) {
    for (const key in obj) delete obj[key];
    return true;
  } else if (cacheElemRefresh && timeSinceCacheElemInit > cacheElemRefresh) {
    obj[prop] = null;
    return true;
  }
}
